==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/files/language/nb.php <==
<?php


$l['name'] = 'Filer';
$l['description'] = 'Filmodul: Modul for å dele filer.';
$l['fileNotFound'] = 'Fant ikke filen';
$l['folderExists'] = 'Mappen finnes fra før';
$l['filenameExists'] = 'Filnavnet finnes fra før';
$l['uploadedSucces'] = 'Filen er lastet opp!';
$l['ootextdoc']='OpenOffice tekst-dokument';
$l['wordtextdoc']='Microsoft Word-dokument';
$l['personal']='Personlig';
$l['shared']='Delt';
$l['general']='Generell';
$l['folder_modified_subject']='Endringer i {product_name} mappen';
$l['folder_modified_body']='Du har bedt om å få beskjed når det er endringer i:
%s
Følgende endringer er foretatt av %s:
%s;
';
$l['modified']='Endret';
$l['new']='Ny';
$l['deleted']='Slettet';
$l['file']='Fil';
$l['folder']='Mappe';
$l['files']='Filer';
$l['emptyFile']='Tom fil';
$l['downloadLink']= 'Nedlastingslenke';
$l['clickHereToDownload']= 'Klikk her for å laste ned filen via en sikker lenke';
$l['copyPasteToDownload']= 'Klikk på den sikre lenken nedenfor eller kopier den inn i adressefeltet i nettleseren din for å laste ned filen.';
$l['possibleUntil']= 'mulig fram til';

$l["files"]='Filer';
$l["template"]= 'Mal';
$l["manageTemplates"]= 'Behandle maler';
$l["downloadTemplate"]= 'Last ned mal';
$l["enterName"]= 'Angi et navn';
$l["pleaseEnterName"]= 'Du må angi et navn';
$l["pleaseEnterNameArchive"]= 'Angi et navn for arkivet';
$l["startTransfer"]= 'Begynn overføring';
$l["addFolder"]= 'Ny mappe';
$l["errorOneItem"]= 'Du kan bare velge ett av alternativene';
$l["activateSharing"]= 'Slå på deling';
$l["notifyChanges"]= 'Gi meg beskjed om endringer i denne mappen';
$l["comments"]= 'Kommentarer';
$l["downloadGOTA"]= 'Last ned med GOTA';
$l["fileBrowser"]= 'Filutforsker';
$l["thumbnails"]= 'Miniatyrbilder';
$l["saveFile"]='Lagre fil';
$l["confirmOverwrite"]='{filename} finnes fra før! Vil du overskrive filen?';
$l["file"]='Fil';
$l["emptyList"]='Tøm liste';
$l["newFiles"]='Ny';
$l["olderVersions"]='Eldre versjoner';
$l["selectFiles"]= 'Velg filer';
$l["uploadProperties"]='Opplysningene nedenfor vil gjelde for alle filer lastet opp med funksjonen "Små filer" ';
$l["fitImage"]='Tilpass bilde';
$l["normalSize"]='Normal størrelse';
$l["imageViewer"]='Bildevisning';
$l["emailDownloadLink"]= 'Send nedlastingslenke i e-post';
$l["expireTime"]= 'Lenken utløper den:';
$l["newFolder"]= 'Ny mappe';
$l["applyState"]= 'Lås mappens visningmodus for alle brukere.';
$l["stateLocked"]= 'Mappens visningsmodus er låst av eier/admin';
$l["strDownloadActive"]= 'Ekstern nedlastingslenke er aktivert';
$l["downloadExpireTime"]='Lenken utløper den';
$l["downloadUrl"]='URL';
$l["categoriesFiles"]= 'Egendefinerte felt for filere';
$l["applyToCurrentFolder"]= 'Gjør disse endringene bare på filene i denne mappen';
$l["applyRecursively"]= 'Gjør disse endringene på filene i denne mappen og alle undermapper';
$l["applyRecursivelyRUSure"]= 'Er du sikker på at du vil gjøre innstillengene for egendefinerte felt gjeldene på ALLE undermapper? Dette kan ha store konsekvenser hvis det er mange undermapper i filtreet.';
$l["pleaseConfirm"]= 'Bekreft';
$l["applyLimits"]= 'Ikke vis alle kategorier for egendefinerte felt';
$l["undef"]= '-';
$l['deletedDownloadLink']='Slett denne lenken';
$l['deleteDownloadLink']='Er du sikker på at du vil slette denne lenken?';
$l['no_folder_id']= 'Serveren har mottatt en ugyldig mappe-ID!';
$l['path']='Filsti';
$l['selectFolder']='Velg mappe...';
$l['notifyRecursiveTitle']='Velg kvittering for undermapper?';
$l['removeNotifyRecursiveTitle']='Fjern kvittering for undermapper?';
$l['notifyRecursiveQuestion']='Vil du gjøre dette for alle undermapper?';
$l['unlock']='Lås opp';
$l['lockedBy']='Låst av';
$l['lock']='Lås';
$l['shortVersion']='Ver.';
$l['fileIsLocked']='Filen er låst';
$l["fileId"]= "ID";
$l["fileFolder_id"]= "Mappe";
$l["fileName"]= "Navn";
$l["fileLocked_user_id"]= "Låst bruker";
$l["fileCtime"]= "Opprettet";
$l["fileMtime"]= "Sist endret";
$l["fileSize"]= "Størrelse";
$l["fileUser_id"]= "Bruker";
$l["fileComment"]= "Kommentar";
$l["fileExtension"]= "Filtype";
$l["fileExpire_time"]= "Utløper";
$l["fileRandom_code"]= "Unik kode";
$l['createDownloadLink']='Lag nedlastningslenke';
$l['notifyFolderAdd']= 'Mappen %s ble opprettet i %s av %s';
$l['notifyFolderRename']= 'Mappen %s fikk endret navn til %s av %s';
$l['notifyFolderMove']= 'Mappen %s ble flyttet til %s av %s';
$l['notifyFolderDelete']= 'Mappen %s ble slettet av %s';
$l['notifyFileAdd']= 'Filen %s ble lagt til i %s av %s';
$l['notifyFileRename']= 'Filen %s fikk endret navn til %s av %s';
$l['notifyFileMove']= 'Filen %s ble flyttet til %s av %s';
$l['notifyFileDelete']= 'Filen %s ble slettet av %s';
$l['notifyFileUpdate']= 'Filen %s ble endret av %s';
$l['notificationEmailSubject']= 'Melding om endringer i mapper';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/files/language/nb.php <==
<?php


$l['name'] = 'Filer';
$l['description'] = 'Filmodul: Modul for å dele filer.';
$l['fileNotFound'] = 'Fant ikke filen';
$l['folderExists'] = 'Mappen finnes fra før';
$l['filenameExists'] = 'Filnavnet finnes fra før';
$l['uploadedSucces'] = 'Filen er lastet opp!';
$l['ootextdoc']='OpenOffice tekst-dokument';
$l['wordtextdoc']='Microsoft Word-dokument';
$l['personal']='Personlig';
$l['shared']='Delt';
$l['general']='Generell';
$l['folder_modified_subject']='Endringer i {product_name} mappen';
$l['folder_modified_body']='Du har bedt om å få beskjed når det er endringer i:
%s
Følgende endringer er foretatt av %s:
%s;
';
$l['modified']='Endret';
$l['new']='Ny';
$l['deleted']='Slettet';
$l['file']='Fil';
$l['folder']='Mappe';
$l['files']='Filer';
$l['emptyFile']='Tom fil';
$l['downloadLink']= 'Nedlastingslenke';
$l['clickHereToDownload']= 'Klikk her for å laste ned filen via en sikker lenke';
$l['copyPasteToDownload']= 'Klikk på den sikre lenken nedenfor eller kopier den inn i adressefeltet i nettleseren din for å laste ned filen.';
$l['possibleUntil']= 'mulig fram til og med';

$l["files"]='Filer';
$l["template"]= 'Mal';
$l["manageTemplates"]= 'Behandle maler';
$l["downloadTemplate"]= 'Last ned mal';
$l["enterName"]= 'Angi et navn';
$l["pleaseEnterName"]= 'Du må angi et navn';
$l["pleaseEnterNameArchive"]= 'Angi et navn for arkivet';
$l["startTransfer"]= 'Begynn overføring';
$l["addFolder"]= 'Ny mappe';
$l["errorOneItem"]= 'Du kan bare velge ett av alternativene';
$l["activateSharing"]= 'Slå på deling';
$l["notifyChanges"]= 'Gi meg beskjed om endringer i denne mappen';
$l["comments"]= 'Kommentarer';
$l["downloadGOTA"]= 'Last ned med GOTA';
$l["fileBrowser"]= 'Filutforsker';
$l["thumbnails"]= 'Miniatyrbilder';
$l["saveFile"]='Lagre fil';
$l["confirmOverwrite"]='{filename} finnes fra før! Vil du overskrive filen?';
$l["file"]='Fil';
$l["emptyList"]='Tøm liste';
$l["newFiles"]='Ny';
$l["olderVersions"]='Eldre versjoner';
$l["selectFiles"]= 'Velg filer';
$l["uploadProperties"]='Opplysningene nedenfor vil gjelde for alle filer lastet opp med funksjonen "Små filer" ';
$l["fitImage"]='Tilpass bilde';
$l["normalSize"]='Normal størrelse';
$l["imageViewer"]='Bildevisning';
$l["emailDownloadLink"]= 'Send nedlastingslenke i e-post';
$l["expireTime"]= 'Lenken utløper den:';
$l["newFolder"]= 'Ny mappe';
$l["applyState"]= 'Lås mappens visningmodus for alle brukere.';
$l["stateLocked"]= 'Mappens visningsmodus er låst av eier/admin';
$l["strDownloadActive"]= 'Ekstern nedlastingslenke er aktivert';
$l["downloadExpireTime"]='Lenken utløper den';
$l["downloadUrl"]='URL';
$l["categoriesFiles"]= 'Egendefinerte felt for filere';
$l["applyToCurrentFolder"]= 'Gjør disse endringene bare på filene i denne mappen';
$l["applyRecursively"]= 'Gjør disse endringene på filene i denne mappen og alle undermapper';
$l["applyRecursivelyRUSure"]= 'Er du sikker på at du vil gjøre innstillengene for egendefinerte felt gjeldene på ALLE undermapper? Dette kan ha store konsekvenser hvis det er mange undermapper i filtreet.';
$l["pleaseConfirm"]= 'Bekreft';
$l["applyLimits"]= 'Ikke vis alle kategorier for egendefinerte felt';
$l["undef"]= '-';
$l['deletedDownloadLink']='Slett denne lenken';
$l['deleteDownloadLink']='Er du sikker på at du vil slette denne lenken?';
$l['no_folder_id']= 'Serveren har mottatt en ugyldig mappe-ID!';
$l['path']='Filsti';
$l['selectFolder']='Velg mappe...';
$l['notifyRecursiveTitle']='Velg kvittering for undermapper?';
$l['removeNotifyRecursiveTitle']='Fjern kvittering for undermapper?';
$l['notifyRecursiveQuestion']='Vil du gjøre dette for alle undermapper?';
$l['unlock']='Lås opp';
$l['lockedBy']='Låst av';
$l['lock']='Lås';
$l['shortVersion']='Ver.';
$l['fileIsLocked']='Filen er låst';
$l["fileId"]= "ID";
$l["fileFolder_id"]= "Mappe";
$l["fileName"]= "Navn";
$l["fileLocked_user_id"]= "Låst av";
$l["fileCtime"]= "Opprettet";
$l["fileMtime"]= "Sist endret";
$l["fileSize"]= "Størrelse";
$l["fileUser_id"]= "Bruker";
$l["fileComment"]= "Kommentar";
$l["fileExtension"]= "Filtype";
$l["fileExpire_time"]= "Utløper";
$l["fileRandom_code"]= "Unik kode";
$l['createDownloadLink']='Lag nedlastningslenke';
$l['notifyFolderAdd']= 'Mappen %s ble opprettet i %s av %s';
$l['notifyFolderRename']= 'Mappen %s fikk endret navn til %s av %s';
$l['notifyFolderMove']= 'Mappen %s ble flyttet til %s av %s';
$l['notifyFolderDelete']= 'Mappen %s ble slettet av %s';
$l['notifyFileAdd']= 'Filen %s ble lagt til i %s av %s';
$l['notifyFileRename']= 'Filen %s fikk endret navn til %s av %s';
$l['notifyFileMove']= 'Filen %s ble flyttet til %s av %s';
$l['notifyFileDelete']= 'Filen %s ble slettet av %s';
$l['notifyFileUpdate']= 'Filen %s ble endret av %s';
$l['notificationEmailSubject']= 'Endringer i mappe';
$l['downloadLinkExpired']= "Beklager, men denne nedlastningslenken er utløpt!";
